import json
import requests

from fisherman import exceptions
from fisherman.utils import colors

# Documentation: https://apility.io/apidocs/#email-check
BASE_URL = "https://api.apility.net/bademail/"

def check_email_rep(email, verbose_flag):
    try:
        colors.print_gray('Casting line - sending email address to Apility')
        request_url = "{apility_url}{email_addr}".format(apility_url=BASE_URL, email_addr=email)
        response = requests.get(request_url)
        if response.status_code == 429:
            raise exceptions.RateLimitException()
        elif response.status_code == 404:
            colors.print_yellow("Apility does not currently have information about this email.")
        elif response.status_code == 200:
            api_data = json.loads(response.content)['response']
            if api_data['email']['score'] < 0 or api_data['address']['score'] < 0 \
                or api_data['score'] < 0:
                colors.print_red("Apility has flagged the email as suspicious.")
            else:
                colors.print_green("Apility has not flagged the email as suspicious.")
            if verbose_flag:
                colors.print_gray(json.dumps(api_data, indent=4))
    except exceptions.RateLimitException:
        colors.print_pink("The ocean has dried up. Try to catch more phish later. Apility has rate limited you.")



import json
import requests

from fisherman import exceptions
from fisherman.utils import colors

# Documentation: https://emailrep.io/docs/
BASE_URL = "https://emailrep.io/"

def check_email_rep(email, verbose_flag):
    try:
        colors.print_gray('Casting line - sending email address to EmailRep')
        request_url = "{email_rep_url}{email_addr}".format(email_rep_url=BASE_URL, email_addr=email)
        response = requests.get(request_url, headers={"Accept": "application/json"})
        if response.status_code == 429:
            raise exceptions.RateLimitException()
        elif response.status_code == 200:
            api_data = json.loads(response.content)
            if api_data['suspicious']:
                colors.print_red("EmailRep has flagged the email as suspicious.")
            else:
                colors.print_green("EmailRep has not flagged the email as suspicious.")
            if verbose_flag:
                colors.print_gray(json.dumps(api_data, indent=4))
    except exceptions.RateLimitException:
        colors.print_pink("The ocean has dried up. Try to catch more phish later. EmailRep has rate limited you.")



def print_red(text):
    print("\033[91m {}\033[00m".format(text))

def print_green(text):
    print("\033[92m {}\033[00m".format(text))

def print_gray(text):
    print("\033[97m {}\033[00m".format(text))

def print_yellow(text):
    print("\033[93m {}\033[00m".format(text))

def print_pink(text):
    print("\033[95m {}\033[00m".format(text))



#!/usr/bin/env python3

from setuptools import setup, find_packages

with open("README.md", "r") as readme_file:
    readme = readme_file.read()

requirements = [
    "requests",
    "validators"
]

setup(
    name="fisherman",
    version="1.0.1",
    author="Edward",
    author_email="14011954+0xedward@users.noreply.github.com",
    license="MIT",
    url="https://github.com/0xedward/fisherman",
    description="A tool for looking up an email address's reputation on EmailRep and Apility without API keys",
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    download_url='https://github.com/0xedward/fisherman/archive/1.0.0.tar.gz',
    install_requires=requirements,
    classifiers=[
        "Topic :: Security",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Natural Language :: English",
    ],
    entry_points={"console_scripts": ["fisherman = fisherman.main:main"]},
    keywords=["security", "phishing"],
)